<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Tietoa </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Tekijä</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Lahjoita</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Ota yhteyttä</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Lisenssi: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Ruudunkaappaus ja merkintätyökalu</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Ota kaappaus</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Tallenna kursori</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Viive</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Kaappaustila</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Näytä kuva ikkunassa</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Kopioi kuva leikepöydälle</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Lataa kuva</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Avaa kuvan hakemisto</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Tallenna kuva</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Piilota pääikkuna</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Toimintojen asetukset</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Toiminta</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Vesileiman kuva vaaditaan</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Lisää vesileiman kuva valitsemalla Vaih­to­eh­dot &gt; Asetukset&gt; Korostus &gt; Päivitä</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Tasainen maalaus</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Kun käytössä, tasoittaa kynän ja
korostuksen piirtämisen jälkeen.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Tasaisuus</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Tasoituskertoimen kasvattaminen pienentää
tarkkuutta kynän ja merkinnän osalta, mutta
tekee tasaisempaa jälkeä.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Korostuksen asetukset</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Muista korostustyökalun valinta ja lataa se käynnistyksen yhteydessä</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Vaihda Valinta-työkaluun piirtämisen jälkeen</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Numerotyökalu päivittää kaikki numeroidut kohteet</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Poistaminen käytöstä muuttaa numerointi-työkalua
ja vaikuttaa vain uusiin kohteisiin, mutta sallii
päällekkäisten numeroiden käytön.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Piirtoalustan väri</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Korostusalueen oletusväri. Värin vaihtaminen
vaikuttaa vain uusiin korostuksiin.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Valitse väline piirtämisen jälkeen</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Kun käytössä, kohde valitaan luomisen jälkeen,
jolloin asetuksia voidaan muuttaa.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Ota ruudunkaappaus käynnistyksen yhteydessä oletustilassa</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Sovelluksen tyyli</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Asettaa sovellusen tyylin ja graafisen käyttöliittymän ulkoasun.
Muutos vaatii ksnipin uudelleen käynnistyksen tullakseen voimaan.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Sovelluksen asetukset</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Kopioi uudet kaappaukset automaattisesti leikepöydälle</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Käytä välilehtiä</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Muutos vaatii käynnistyksen.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Suorita ksnip yhtenä esiintymänä</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Piilota välilehtipalkki, kun vain yhtä välilehteä käytetään.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Jos asetus käytössä, vain yksi ksnip voidaan suorittaa, kaikki
muut tapaukset, jotka on aloitettu sen jälkeen läpäisevät
argumentit ensimmäiselle ja sulkeutuu. Asetuksen muutos
edellyttää käynnistyksen kaikille esiintymille.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Muista pääikkunan sijainti liikkuessa ja käynnistyksen yhteydessä</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Piilota välilehdet automaattisesti</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Piilota paneelit automaattisesti</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Käynnistyksessä piilota työkalupalkki ja korostuksen asetukset.
Valikon näkyvyyttä voidaan vaihtaa sarkaimella.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Muuta kokoa automaattisesti</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Muuttaa pääikkunan kokoa automaattisesti kuvaan sopivaksi.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Ota virheenkorjaus käyttöön</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Ottaa käyttöön konsoliin kirjoitettavan debug-listauksen.
Muutos vaatii ksnipin käynnistyksen tullakseen voimaan.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation>Muuta kokoa sisällön viiveen mukaan</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Sisällön koon muuttaminen viivästyy, jotta Ikkunanhallinta voi vastaanottaa
uutta sisältöä. Jos pääikkunaa ei ole säädetty oikein uuteen sisältöön,
viiveen lisääminen saattaa parantaa toimintaa.</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Kehittäjät:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Espanjan käännökset</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Hollannin käännökset</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Venäjän käännökset</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Norjan käännökset</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Ranskan käännökset</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Puolan käännökset</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Tuettu Snap &amp; Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Tekijät:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Varoitus - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Kaappausta %1%2%3 on muokattu.
Haluatko tallentaa sen?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Uusi</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Piirrä hiirellä suorakaiteen muotoinen alue</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Kaappaa koko näyttö, mukaan lukien kaikki näytöt</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Kaappaa näyttö, jossa hiiri sijaitsee</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Kaappaa ikkuna, joka on tällä hetkellä aktiivinen</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Kaappaa se, joka on hiiren kursorin alla</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Ota ruudunkaappaus viimeksi valitusta suorakulmaisesta alueesta</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Käytä kuvalle portaalia otettuasi ruudunkaappauksen</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Yhteisö</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Virheraportit</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Jos sinulla on kysymyksiä, ideoita tai haluat vain puhua ksnipistä,&lt;br/&gt;liity %1 tai %2-palvelimelle.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Ilmoita virheistä %1 toiminnolla.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Kopioiminen leikepöydälle epäonnistui</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Leikepöydälle kopioiminen epäonnistui base64-koodattulla kuvalla.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Kopioitu leikepöydälle</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Kopioitu leikepöydälle base64-koodattuna kuvana.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Poista kuva</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Kohde &quot;%1&quot; poistetaan.
Haluatko jatkaa?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Lahjoitukset ovat aina tervetulleita</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Lahjoitus</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip on voittoa tavoittelematon ohjelmaisto projekti. &lt;br/&gt;Silti joitakin kustannuksia on katettava,&lt;br/&gt; kuten verkkotunnus ja laitteistokulua alustojen välisen tuen testaamisesi.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Jos haluat auttaa tai vain arvostaa tehtyä työtä&lt;br/&gt; tarjoamalla kehittäjille oluen tai kahvin, voit tehdä sen %1 täällä %2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Ryhdy GitHub-sponsoriksi?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Mahdollista myös, %1 täällä %2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Lisää uusia toimintoja painamalla &quot;Lisää&quot; välilehden painiketta.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Suorakulmainen alue</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Viimeisin suorakulmainen alue</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Koko näyttö (kaikki näytöt)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Nykyinen näyttö</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Aktiivinen ikkuna</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Ikkuna kohdistimen alla</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Ruudunkaappaus portaali</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Pakota anonyymi lataus.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP-lataaja</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Lataaminen onnistui</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Väliaikaista kuvaa ei voi tallentaa lähetettäväksi.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Prosessia ei voi aloittaa, tarkista polku ja käyttöoikeudet.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Prosessi kaatui</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Prosessi aikakatkaistiin.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Prosessin lukuvirhe.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Prosessin kirjoitusvirhe.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Verkkovirhe, tarkista konsolin tulos.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Lataaminen epäonnistui</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Skriptin kirjoitti StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>FTP-lataus päättyi onnistuneesti.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Tuntematon virhe.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Yhteysvirhe.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Käyttöoikeusvirhe.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>Scriptin %1  lataus päättyi onnistuneesti.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Ladattu %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Ota pikanäppäimet käyttöön</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Kaappaa valitsemasi alue</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Kaappaa koko näyttö</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Kaappaa nykyinen näyttö</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Kaappaa aktiivinen ikkuna</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Kaappaa ikkuna kohdistimen alla</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Pikanäppäimet</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Kaappaa valitsemasi alue uudelleen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Kaappaa portaaliin</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Pikanäppäimiä tuetaan vain X11 ikkunassa tällä hetkellä.
Poistamalla toiminnon käytöstä, pikanäppäimet ovat vain ksnipille.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Kaappaa hiiren osoitin kuvaan</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Pitäisikö hiiren osotin näkyä
kaappauksissa.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Kuvan kaappaaja</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Yleiset Wayland-toteutukset, jotka käyttävät
tapaa XDG-DESKTOP-PORTAL käsittelevät
skaalautumista eri tavalla. Käyttöönotto
määrittää näytön nykyisen skaalauksen ja
soveltaa sitä ksnipin kaappaukseen.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME ja KDE Plasma tukevat heidän omaa Waylandia.
ja yleiset XDG-DESKTOP-PORTAL ruudunkaappausta.
Tämän ottaminen käyttöön, pakottaa KDE Plasman ja
GNOME:n käyttämään XDG-DESKTOP-PORTAL ruurun-
kaappausta. Vaatii ksnipin käynnistyksen uudelleen.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Näytä pääikkuna kaappauksen jälkeen</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Piilota pääikkuna kaappauksen aikana</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Piilota pääikkuna, kun otat uuden kaappauksen.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Näytä pääikkuna kaappauksen ottamisen jälkeen kun
pääikkuna oli piilotettu tai minimoitu.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Pakota Wayland (xdg-desktop-portal) ruudunkaappaus</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Skaalaa Wayland (xdg-desktop-portal) ruudunkaappaus</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur-historia</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Aikaleima</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Linkki</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Poista linkki</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Lähetys osoitteeseen imgur.com valmis!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Uusi tunnus vastaanotettu, yritetään ladata uudelleen…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur-tunnus on vanhentunut, pyydetään uutta tunnusta…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Pakota anonyymi lataus</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Kopioi aina Imgur-linkki leikepöydälle</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Asiakkaan tunnus</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Asiakkaan salaus</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Anna imgur pin, joka vaihdetaan tunnukseksi.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Hanki PIN-koodi</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Hanki tunnus</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur-historia</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur lataaja</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Odotetaan sivustoa imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com-tunnuksen päivitys onnistui.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Imgur.com-tunnuksen päivitysvirhe.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Lataamisen jälkeen avaa Imgur-linkki oletus selaimessa</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Linkitä suoraan kuvaan</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Verkko-osoite:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Verkko-osoite, jota käytetään viestintään Imgurin kanssa.
Muuttaminen vaatii ohjelman käynnistyksen uudelleen.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Tyhjennä tunnus</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Kuvaa ei voi avata</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Kuvaa ei voi avata polusta %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Uusi</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Laukaisun viive sekunteina kaappauksen
ottamisen välillä.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Tallenna kaappaus kiintolevylle</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Kopioi kaappaus leikepöydälle</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Työkalut</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Toista</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Rajaa</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Rajaa ruudunkaappaus</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Tallentamaton</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Lähetä</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tulosta</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Avaa tulostinikkunan ja antaa mahdollisuuden kuvan tulostamiseen</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Tulostuksen esikatselu</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Avaa tulostuksen esikatseluikkuna, jossa kuvan suuntaa voidaan muuttaa</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skaalaus</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Lisäasetukset</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Lisää vesileima</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Lisää vesileima kaapattuun kuvaan. Vesileimoja voi lisätä useita.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Kuvaa ei voi näyttää</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Tallenna nimellä...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Liitä</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Liitä upotettuna</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Kiinnitä</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Kiinnitä kaappaus etualalle kehyksettömässä ikkunassa</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Kuvaa ei toimitettu, mutta sellaista odotettiin.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopioi polku</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Näytä</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Avaa kuvat</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Näytä paneeli</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Piilota paneeli</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Kopioi datana URI</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>Avaa &amp;viimeisin</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Muokkaa piirtoalustaa</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Lataa triggerCapture ulkoiseen lähteeseen</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Kopioi triggerCapture leikepöydälle</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Skaalaa kuva</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Pyöritä</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Pyöritä kuvaa</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Toimet</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Kuvatiedostot</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Tallenna nimellä</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Kopion polku</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Kaappaa</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Sulje muut</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Sulje kaikki</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Kiinnitä ikkuna %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Kuva nimetty</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Kuvan nimeäminen epäonnistui</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Nimeä kuva uudelleen</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Uusi tiedostonimi:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Kuvan nimi muutettiin onnistuneesti muotoon %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Kuvan nimeäminen muotoon %1 epäonnistui</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Tallenna nimellä</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Kaikki tiedostot</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Kuva tallennettu</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Kuvan tallentaminen epäonnistui</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Kuvatiedostot</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Tallennettu %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Kuvan tallentaminen %1 epäonnistui</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Tallenna uudet kaappaukset automaattisesti oletussijaintiin</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Pyydä tallentamista, ennen kuin hylkäät muutokset</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Muista viimeisin tallennuskansio</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Kun käytössä, se korvaa asetuksiin tallennetun kansion uusimman
tallennuksen mukaan jokaisella tallennuskerralla.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Kaappauksen tallennuspaikka ja tiedostonimi</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Tuetut formaatit ovat JPG, PNG ja BMP. Jos mitään päätettä ei ole annettu, PNG on oletus.
Tiedostonimi voi sisältää seuraavia merkkejä:
- $Y, $M, $D päivämäärälle, $h, $m, $s ajalle tai $T ajalle hhmmss-muodossa.
- Useita peräkkäisiä #-merkkejä laskurille. #### antaa tulokseksi 0001, seuraava kaappaus olisi 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Selaa</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Säästäjän asetukset</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Kaappauksen tallennussijainti</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Kerroin</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Tallenna laatu</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Määritä 0, jos haluat hankkia pieniä pakattuja tiedostoja, 100 suurille pakkaamattomille
tiedostoille. Kaikki kuvamuodot eivät tue täyttä aluetta, mutta JPEG tukee.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Kopioi skriptin tulos leikepöydälle</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Skripti:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Polku skriptiin, jota kutsutaan latausta varten. Latauksen aikana skriptiä kutsutaan
väliaikaisen png-tiedoston polun kanssa yhtenä argumenttina.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Selaa</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Skriptin lataaja</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Valitse lähetävä skripti</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Lopeta, kun latausskripti kirjoittaa StdErr</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Merkitsee lataus epäonnistuneeksi, kun skripti kirjoittaa StdErr-tiedostoon.
Ilman tätä asetusta skriptin virheet jäävät huomaamatta.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Suodatin:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>RegEx-lauseke. Kopioi leikepöydälle vain, mikä vastaa RegEx-lauseketta.
Kun kaikki jätetään pois, kaikki kopioidaan.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Kuvan kaappaaja</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur lataaja</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Sovellus</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Huomautus</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Pikanäppäimet</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Lataaja</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Skriptin lataaja</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Säästäjä</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Tarrat</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Leikkausalue</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Paneelin kuvake</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Vesileima</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Toimet</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP-lataaja</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Muuta valitun suorakulman kokoa kahvoilla tai siirrä sitä vetämällä valintaa.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Siirrä valintaa nuolinäppäimillä.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Siirrä vasenta yläkahvaa nuolinäppäimillä ja paina samalla CTRL-näppäintä.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Siirrä oikeaa alakahvaa nuolinäppäimillä ja paina samalla ALT-näppäintä.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Vahvista valinta painamalla ENTER/RETURN tai keskeytä painamalla ESC.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Tämä viesti voidaan poistaa käytöstä asetuksissa.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Valitse suorakulmainen alue napsauttamalla ja vetämällä tai lopeta painamalla ESC.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Pidä CTRL-näppäintä painettuna, kun haluat muuttaa valinnan kokoa jälkeenpäin.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Pidä CTRL-näppäintä painettuna estääksesi koon muuttamisen valinnan jälkeen.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>Toiminto peruutetaan 60 sekunnin kuluttua, jos valintaa ei ole tehty.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Tämä viesti voidaan poistaa käytöstä asetuksissa.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Pysäytä kuva leikkaamisen aikana</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Kun asetus on käytössä, tausta pysähtyy ja
valittaan suorakulmaista alue. Muuttaa myös
viiveen käyttäytymistä, sillä viive tapahtuu
ennen kuin leikkausalue näytetään.
Kun asetus on pois käytöstä viive tapahtuu
leikkausalueen näyttämisen jälkeen.
Ominaisuus on aina pois käytöstä Waylandissa
ja MacOS aina käytössä.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Näytä suurennuslasi leikkausalueella</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Näytä suurennuslasi, joka zoomaa taustakuvaa.
Tämä vaihtoehto toimii vain kun ominaisuus
&quot;Pysäytä kuva leikkauksen aikana&quot; on käytössä.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Näytä leikkausalueen viivaimet</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Vaaka- ja pystyviivat, jotka kulkevat työpöydän
reunoista kohdistimeen leikkausalueella.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Näytä leikkausalueen sijainti ja koko</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Kun hiiren vasenta painiketta ei paineta, sijainti
näytetään, kun taas hiiren painiketta painetaan,
valinta-alueen koko näkyy vasemmalla ja sen
yläpuolelta kaapatulta alueelta.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Salli alueen valinnan muuttaminen oletuksena</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Kun asetus on käytössä, suorakulmaisen alueen
valitsemisen jälkeen, se sallii valinnan koon
muuttamisen. Kun koon muuttaminen on tehty,
valinta vahvistetaan askelpalautin-näppäimellä.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Näytä leikkausalueen infoteksti</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Leikkausalueen kohdistimen väri</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Asettaa leikkausalueen kohdistimen värin.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Leikkausalueen kohdistimen paksuus</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Asettaa leikkausalueen kohdistimen paksuuden.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Leikkausalue</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Leikkausalueen merkintäväri</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Asettaa kaikkien merkintä-elementtien
värin leikkausalueella.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Leikkausalueen läpinäkyvyys</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Alpha-arvo ei valittulla leikkausalueella.
Pienempi numero on läpinäkyvämpi.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Alas</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Käytä oletus tarroja</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Tarran asetukset</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Vektorikuva (* .svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Lisää tarroja</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Näytä muokkain</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Käytä paneelin kuvaketta</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Kun asetus käytössä, se lisää alavalikon kuvakkeen, jos käyttöjärjestelmä sitä tukee.
Muutos vaatii käynnistämisen uudelleen.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Pienennä alavalikkoon</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Käynnistä pienennettynä alavalikkoon</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Sulje alavalikkoon</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Näytä muokkain</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Kaappaa</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Kuvakkeen oletustoiminto alavalikossa</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Oletustoiminto, napsauttamalla hiiren vasen alavalikon kuvakeessa.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Alavalikon kuvakkeen asetukset</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Käytä alustakohtaista ilmoituspalvelua</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Kun asetus on käytössä, se yrittää käyttää alustakohtaista ilmoitusta,
palvelua, jos sellainen on olemassa. Vaatii käynnistyksen uudelleen.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Näytä alavalikon kuvakkeen ilmoitukset</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Valitse kuva</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Kuvatiedostot</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Latausskripti vaaditaan</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Lisää latausskripti valitsemalla Valinnat &gt; Asetukset &gt; Latausskripti</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Kaappauksen lataus</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Olet lataamassa kuvaa ulkoiseen kohteeseen, haluatko jatkaa?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Pyydä vahvistusta ennen lataamista</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Lataajan tyyppi:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur palvelu</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Skripti</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Lataaja</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Käännös</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Käyttäen:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Vesileiman kuva</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Päivitys</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Pyöritä vesileimaa</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Kun tämä on käytössä, vesileima lisätään kiertämällä 45°</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Vesileiman asetukset</translation>
    </message>
</context>
</TS>
